contexttools.detach_all_context_marks_attached_to_component
===========================================================

.. autofunction:: abjad.tools.contexttools.detach_all_context_marks_attached_to_component
